SingleOwnerAccount

Struct SingleOwnerAccount 

pub struct SingleOwnerAccount<P, S>
where P: Provider + Send, S: Signer + Send,
{ /* private fields */ }
A generic Account implementation for controlling account contracts that only have one signer using ECDSA the STARK curve.

Implementations

Source

impl<P, S> SingleOwnerAccount<P, S>
where P: Provider + Sync + Send, S: Signer + Sync + Send,

pub const fn new( provider: P, signer: S, address: Felt, chain_id: Felt, encoding: ExecutionEncoding, ) -> SingleOwnerAccount<P, S>

Create a new account controlled by a single signer.

Parameters
  • provider: A Provider implementation that provides access to the Starknet network.
  • signer: A Signer implementation that can generate valid signatures for this account.
  • address: Account contract address.
  • chain_id: Network chain ID.
  • encoding: How __execute__ calldata should be encoded.
pub fn set_block_id(&mut self, block_id: BlockId) -> &SingleOwnerAccount<P, S>

Sets a new block ID to run queries against.