Module contract

Module contract 

Types for smart contract deployment and interaction

Structs

ContractFactory
A contract factory that acts as a blueprint for deploying Starknet smart contracts using the Universal Deployer Contract.
DeploymentV3
Abstraction over contract deployment via the UDC. This type uses INVOKE v3 transactions under the hood, and hence pays transaction fees in STRK.

Enums

UdcSelector
Specifies the Universal Deployer Contract to be used.