UdcSelector

Enum UdcSelector 

pub enum UdcSelector {
    Legacy,
    New,
    Custom(Felt),
}
Specifies the Universal Deployer Contract to be used.

Variants



Legacy

The original, now deprecated, deployer contract deployed at 0x041a78e741e5af2fec34b695679bc6891742439f7afb8484ecd7766661ad02bf.



New

The latest deployer contract deployed at 0x02ceed65a4bd731034c01113685c831b01c15d7d432f71afb1cf1634b53a2125.



Custom(Felt)

Custom compatible deployer contract instance.

Implementations

Source

impl UdcSelector

pub const fn address(&self) -> Felt

Gets the contract address of the selected Universal Deployer Contract instance.