pub struct DeploymentV3<'f, A> { /* private fields */ }Expand description
Abstraction over contract deployment via the UDC. This type uses INVOKE v3 transactions under
the hood, and hence pays transaction fees in STRK.
Implementations
Sourceimpl<A> DeploymentV3<'_, A>
impl<A> DeploymentV3<'_, A>
Sourcepub fn nonce(self, nonce: Felt) -> DeploymentV3<'_, A>
pub fn nonce(self, nonce: Felt) -> DeploymentV3<'_, A>
Returns a new DeploymentV3 with the nonce.
Sourcepub fn l1_gas(self, l1_gas: u64) -> DeploymentV3<'_, A>
pub fn l1_gas(self, l1_gas: u64) -> DeploymentV3<'_, A>
Returns a new DeploymentV3 with the l1_gas.
Sourcepub fn l1_gas_price(self, l1_gas_price: u128) -> DeploymentV3<'_, A>
pub fn l1_gas_price(self, l1_gas_price: u128) -> DeploymentV3<'_, A>
Returns a new DeploymentV3 with the l1_gas_price.
Sourcepub fn l2_gas(self, l2_gas: u64) -> DeploymentV3<'_, A>
pub fn l2_gas(self, l2_gas: u64) -> DeploymentV3<'_, A>
Returns a new DeploymentV3 with the l2_gas.
Sourcepub fn l2_gas_price(self, l2_gas_price: u128) -> DeploymentV3<'_, A>
pub fn l2_gas_price(self, l2_gas_price: u128) -> DeploymentV3<'_, A>
Returns a new DeploymentV3 with the l2_gas_price.
Sourcepub fn l1_data_gas(self, l1_data_gas: u64) -> DeploymentV3<'_, A>
pub fn l1_data_gas(self, l1_data_gas: u64) -> DeploymentV3<'_, A>
Returns a new DeploymentV3 with the l1_data_gas.
Sourcepub fn l1_data_gas_price(self, l1_data_gas_price: u128) -> DeploymentV3<'_, A>
pub fn l1_data_gas_price(self, l1_data_gas_price: u128) -> DeploymentV3<'_, A>
Returns a new DeploymentV3 with the l1_data_gas_price.
Sourcepub fn gas_estimate_multiplier(
self,
gas_estimate_multiplier: f64,
) -> DeploymentV3<'_, A>
pub fn gas_estimate_multiplier( self, gas_estimate_multiplier: f64, ) -> DeploymentV3<'_, A>
Returns a new DeploymentV3 with the gas amount estimate multiplier. The multiplier is
used when the gas amount is not manually specified and must be fetched from a
Provider instead.
Sourcepub fn gas_price_estimate_multiplier(
self,
gas_price_estimate_multiplier: f64,
) -> DeploymentV3<'_, A>
pub fn gas_price_estimate_multiplier( self, gas_price_estimate_multiplier: f64, ) -> DeploymentV3<'_, A>
Returns a new DeploymentV3 with the gas price estimate multiplier. The multiplier is
used when the gas price is not manually specified and must be fetched from a
Provider instead.
Sourcepub fn tip(self, tip: u64) -> DeploymentV3<'_, A>
pub fn tip(self, tip: u64) -> DeploymentV3<'_, A>
Returns a new DeploymentV3 with the tip.
Sourceimpl<A> DeploymentV3<'_, A>where
A: Account,
impl<A> DeploymentV3<'_, A>where
A: Account,
Sourcepub fn deployed_address(&self) -> Felt
pub fn deployed_address(&self) -> Felt
Calculate the resulting contract address without sending a transaction.
Sourceimpl<A> DeploymentV3<'_, A>where
A: ConnectedAccount + Sync,
impl<A> DeploymentV3<'_, A>where
A: ConnectedAccount + Sync,
Sourcepub async fn estimate_fee(
&self,
) -> Result<FeeEstimate, AccountError<<A as Account>::SignError>>
pub async fn estimate_fee( &self, ) -> Result<FeeEstimate, AccountError<<A as Account>::SignError>>
Estimates transaction fees from a Provider.
Sourcepub async fn simulate(
&self,
skip_validate: bool,
skip_fee_charge: bool,
) -> Result<SimulatedTransaction, AccountError<<A as Account>::SignError>>
pub async fn simulate( &self, skip_validate: bool, skip_fee_charge: bool, ) -> Result<SimulatedTransaction, AccountError<<A as Account>::SignError>>
Simulates the transaction from a Provider. Transaction
validation and fee transfer can be skipped.
Sourcepub async fn send(
&self,
) -> Result<InvokeTransactionResult, AccountError<<A as Account>::SignError>>
pub async fn send( &self, ) -> Result<InvokeTransactionResult, AccountError<<A as Account>::SignError>>
Signs and broadcasts the transaction to the network.