pub enum EcdsaVerifyError {
MessageHashOutOfRange,
InvalidPublicKey,
SignatureROutOfRange,
SignatureSOutOfRange,
}Expand description
Errors when performing ECDSA verify operations.
Variants
MessageHashOutOfRange
The message hash is not in the range of [0, 2^251).
InvalidPublicKey
The public key is not a valid point on the STARK curve.
SignatureROutOfRange
The r value is not in the range of [0, 2^251).
SignatureSOutOfRange
The s value is not in the range of [0, 2^251).