pub struct HashFunction { /* private fields */ }Expand description
A hash function that is used in Starknet.
Implementations
Sourceimpl HashFunction
impl HashFunction
Sourcepub fn stateful(&self) -> StatefulHasher
pub fn stateful(&self) -> StatefulHasher
Creates a new stateful hasher with chosen hash function.
Sourcepub fn poseidon() -> HashFunction
pub fn poseidon() -> HashFunction
Creates a new Poseidon hash function.
Sourcepub fn blake2s() -> HashFunction
pub fn blake2s() -> HashFunction
Creates a new Blake2s hash function.
Sourcepub fn hash(&self, x: Felt, y: Felt) -> Felt
pub fn hash(&self, x: Felt, y: Felt) -> Felt
Computes the Starknet Poseidon hash of x and y with chosen hash function.
Sourcepub fn hash_single(&self, input: Felt) -> Felt
pub fn hash_single(&self, input: Felt) -> Felt
Computes the Starknet hash of a single Felt with chosen hash function.