short_string!() { /* proc-macro */ }Expand description
Defines a compile-time constant for a Cairo short string encoding from a human-readable string.
short_string!() { /* proc-macro */ }Defines a compile-time constant for a Cairo short string encoding from a human-readable string.