pub enum JsonRpcErrorConversionError {
UnknownCode,
MissingData,
DataParsingFailure,
}Expand description
Failures trying to parse a JsonRpcError into StarknetError.
StarknetError is the standard, provider-agnostic error type that all Provider
implementations should strive to return in an error case, in a best-effort basis. This allows
for unified error handling logic.
However, not all error cases can be properly converted, and this error type represents the cases when such failure happens.
Variants
UnknownCode
The error code is outside of the range specified by the specification.
MissingData
Error data is expected but missing.
DataParsingFailure
Error data is malformed.