pub struct DeclareV1TransactionRequest {
pub contract_class: Arc<CompressedLegacyContractClass>,
pub sender_address: Felt,
pub max_fee: Felt,
pub signature: Vec<Felt>,
pub nonce: Felt,
pub is_query: bool,
}Fields
contract_class: Arc<CompressedLegacyContractClass>sender_address: FeltThe address of the account contract sending the declaration transaction.
max_fee: FeltThe maximal fee to be paid in Wei for declaring a contract class.
signature: Vec<Felt>Additional information given by the caller that represents the signature of the transaction.
nonce: FeltA sequential integer used to distinguish between transactions and order them.
is_query: boolTrait Implementations
Sourceimpl Debug for DeclareV1Transaction
impl Debug for DeclareV1Transaction
Sourceimpl Serialize for DeclareV1Transaction
impl Serialize for DeclareV1Transaction
Sourcefn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
Serialize this value into the given Serde serializer. Read more