pub struct DeclareV2TransactionRequest {
pub contract_class: Arc<CompressedSierraClass>,
pub compiled_class_hash: Felt,
pub sender_address: Felt,
pub max_fee: Felt,
pub signature: Vec<Felt>,
pub nonce: Felt,
pub is_query: bool,
}Fields
contract_class: Arc<CompressedSierraClass>compiled_class_hash: FeltHash of the compiled class obtained by running starknet-sierra-compile on the Sierra
class. This is required because at the moment, Sierra compilation is not proven, allowing
the sequencer to run arbitrary code if this is not signed. It’s expected that in the future
this will no longer be required.
sender_address: FeltThe address of the account contract sending the declaration transaction.
max_fee: FeltThe maximal fee to be paid in Wei for declaring a contract class.
signature: Vec<Felt>Additional information given by the caller that represents the signature of the transaction.
nonce: FeltA sequential integer used to distinguish between transactions and order them.
is_query: boolTrait Implementations
Sourceimpl Debug for DeclareV2Transaction
impl Debug for DeclareV2Transaction
Sourceimpl Serialize for DeclareV2Transaction
impl Serialize for DeclareV2Transaction
Sourcefn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
Serialize this value into the given Serde serializer. Read more