DeclareV3TransactionRequest

Struct DeclareV3TransactionRequest 

pub struct DeclareV3TransactionRequest {
    pub contract_class: Arc<CompressedSierraClass>,
    pub compiled_class_hash: Felt,
    pub sender_address: Felt,
    pub signature: Vec<Felt>,
    pub nonce: Felt,
    pub nonce_data_availability_mode: DataAvailabilityMode,
    pub fee_data_availability_mode: DataAvailabilityMode,
    pub resource_bounds: ResourceBoundsMapping,
    pub tip: u64,
    pub paymaster_data: Vec<Felt>,
    pub account_deployment_data: Vec<Felt>,
    pub is_query: bool,
}

Fields

contract_class: Arc<CompressedSierraClass>compiled_class_hash: Felt

Hash of the compiled class obtained by running starknet-sierra-compile on the Sierra class. This is required because at the moment, Sierra compilation is not proven, allowing the sequencer to run arbitrary code if this is not signed. It’s expected that in the future this will no longer be required.

sender_address: Felt

The address of the account contract sending the declaration transaction.

signature: Vec<Felt>

Additional information given by the caller that represents the signature of the transaction.

nonce: Felt

A sequential integer used to distinguish between transactions and order them.

nonce_data_availability_mode: DataAvailabilityModefee_data_availability_mode: DataAvailabilityModeresource_bounds: ResourceBoundsMappingtip: u64paymaster_data: Vec<Felt>account_deployment_data: Vec<Felt>is_query: bool