SequencerGatewayProvider

Struct SequencerGatewayProvider 

pub struct SequencerGatewayProvider { /* private fields */ }

Implementations

Source

impl SequencerGatewayProvider

pub fn new( gateway_url: impl Into<Url>, feeder_gateway_url: impl Into<Url>, chain_id: Felt, ) -> SequencerGatewayProvider

pub fn new_with_client( gateway_url: impl Into<Url>, feeder_gateway_url: impl Into<Url>, chain_id: Felt, client: Client, ) -> SequencerGatewayProvider

pub fn starknet_alpha_mainnet() -> SequencerGatewayProvider

pub fn starknet_alpha_sepolia() -> SequencerGatewayProvider

pub fn with_header( self, name: String, value: String, ) -> SequencerGatewayProvider

Consumes the current SequencerGatewayProvider instance and returns a new one with the header appended. Same as calling add_header.

pub fn add_header(&mut self, name: String, value: String)

Adds a custom HTTP header to be sent for requests to the sequencer.

Source

impl SequencerGatewayProvider

pub async fn add_transaction( &self, tx: TransactionRequest, ) -> Result<AddTransactionResult, ProviderError>

👎Deprecated: Sequencer-specific functions are deprecated. Use it via the Provider trait instead.
pub async fn get_contract_addresses( &self, ) -> Result<ContractAddresses, ProviderError>

👎Deprecated: Sequencer-specific functions are deprecated. Use it via the Provider trait instead.
pub async fn get_block( &self, block_identifier: BlockId, ) -> Result<Block, ProviderError>

👎Deprecated: Sequencer-specific functions are deprecated. Use it via the Provider trait instead.
pub async fn get_state_update( &self, block_identifier: BlockId, ) -> Result<StateUpdate, ProviderError>

👎Deprecated: Sequencer-specific functions are deprecated. Use it via the Provider trait instead.
pub async fn get_state_update_with_block( &self, block_identifier: BlockId, ) -> Result<StateUpdateWithBlock, ProviderError>

👎Deprecated: Sequencer-specific functions are deprecated. Use it via the Provider trait instead.
pub async fn get_compiled_class_by_class_hash( &self, class_hash: Felt, block_identifier: BlockId, ) -> Result<CompiledClass, ProviderError>

👎Deprecated: Sequencer-specific functions are deprecated. Use it via the Provider trait instead.
pub async fn get_class_by_hash( &self, class_hash: Felt, block_identifier: BlockId, ) -> Result<DeployedClass, ProviderError>

👎Deprecated: Sequencer-specific functions are deprecated. Use it via the Provider trait instead.
pub async fn get_transaction_status( &self, transaction_hash: Felt, ) -> Result<TransactionStatusInfo, ProviderError>

👎Deprecated: Sequencer-specific functions are deprecated. Use it via the Provider trait instead.
pub async fn get_transaction( &self, transaction_hash: Felt, ) -> Result<TransactionInfo, ProviderError>

👎Deprecated: Sequencer-specific functions are deprecated. Use it via the Provider trait instead.
pub async fn get_block_hash_by_id( &self, block_number: u64, ) -> Result<Felt, ProviderError>

👎Deprecated: Sequencer-specific functions are deprecated. Use it via the Provider trait instead.
pub async fn get_block_id_by_hash( &self, block_hash: Felt, ) -> Result<u64, ProviderError>

👎Deprecated: Sequencer-specific functions are deprecated. Use it via the Provider trait instead.
pub async fn get_last_batch_id(&self) -> Result<u64, ProviderError>

👎Deprecated: Sequencer-specific functions are deprecated. Use it via the Provider trait instead.
pub async fn get_l1_blockchain_id(&self) -> Result<u64, ProviderError>

👎Deprecated: Sequencer-specific functions are deprecated. Use it via the Provider trait instead.