pub enum LedgerError {
InvalidDerivationPath,
TransportError(LedgerError),
UnknownResponseCode(u16),
UnsuccessfulRequest(APDUResponseCodes),
UnexpectedResponseLength {
expected: usize,
actual: usize,
},
}Expand description
Errors using the Ledger hardware wallet.
Variants
InvalidDerivationPath
The HD wallet derivation path is malformed or does not conform to EIP-2645.
TransportError(LedgerError)
Error communicating with the Ledger hardware device.
UnknownResponseCode(u16)
An unknown response code is returned from the device.
UnsuccessfulRequest(APDUResponseCodes)
The response code returned from the device does not indicate success.
UnexpectedResponseLength
The response has an unexpected size.