pub struct DerivationPath(/* private fields */);Expand description
A Bip32 derivation path
Implementations
Sourceimpl DerivationPath
impl DerivationPath
Sourcepub fn last(&self) -> Option<&u32>
pub fn last(&self) -> Option<&u32>
Return the last index in the path. None if the path is the root.
Sourcepub fn derivation_string(&self) -> String
pub fn derivation_string(&self) -> String
Converts the path to a standard bip32 string. e.g "m/44'/0'/0/32".
Sourcepub fn starts_with(&self, other: &DerivationPath) -> bool
pub fn starts_with(&self, other: &DerivationPath) -> bool
true if other is a prefix of self
Sourcepub fn without_prefix(&self, prefix: &DerivationPath) -> Option<DerivationPath>
pub fn without_prefix(&self, prefix: &DerivationPath) -> Option<DerivationPath>
Remove a prefix from a derivation. Return a new DerivationPath without the prefix. This is useful for determining the path to rech some descendant from some ancestor.
Sourcepub fn last_hardened(&self) -> (usize, Option<u32>)
pub fn last_hardened(&self) -> (usize, Option<u32>)
Convenience function for finding the last hardened derivation in a path. Returns the index and the element. If there is no hardened derivation, it will return (0, None).
Sourcepub fn resized(&self, size: usize, pad_with: u32) -> DerivationPath
pub fn resized(&self, size: usize, pad_with: u32) -> DerivationPath
Return a clone with a resized path. If the new size is shorter, this truncates it. If the new path is longer, we pad with the second argument.
Sourcepub fn extended(&self, idx: u32) -> DerivationPath
pub fn extended(&self, idx: u32) -> DerivationPath
Append an additional derivation to the end, return a clone