LedgerSigner

Struct LedgerSigner 

pub struct LedgerSigner<T = Ledger> { /* private fields */ }
Ledger app wrapper that implements the Signer trait.

Implementations

Source

impl LedgerSigner

pub async fn new( derivation_path: DerivationPath, ) -> Result<LedgerSigner, LedgerError>

Initializes the Starknet Ledger app. Attempts to find and connect to a Ledger device. The device must be unlocked and have the Starknet app open.

The derivation_path passed in must follow EIP-2645, i.e. having 2645' as its “purpose” level as per BIP-44, as the Ledger app does not allow other paths to be used.

The path must also be 6-level in length. An example path for Starknet would be:

m/2645'/1195502025'/1470455285'/0'/0'/0

where:

  • 2645' is the EIP-2645 prefix
  • 1195502025', decimal for 0x4741e9c9, is the 31 lowest bits for sha256(starknet)
  • 1470455285', decimal for 0x57a55df5, is the 31 lowest bits for sha256(starkli)

Currently, the Ledger app only enforces the length and the first level of the path.

Source

impl<T> LedgerSigner<T>

pub fn new_with_app( derivation_path: DerivationPath, app: LedgerStarknetApp<T>, ) -> Result<LedgerSigner<T>, LedgerError>

Creates a Starknet Ledger signer with an already initialized Ledger app.

The derivation_path passed in must follow EIP-2645, i.e. having 2645' as its “purpose” level as per BIP-44, as the Ledger app does not allow other paths to be used.

The path must also be 6-level in length. An example path for Starknet would be:

m/2645'/1195502025'/1470455285'/0'/0'/0

where:

  • 2645' is the EIP-2645 prefix
  • 1195502025', decimal for 0x4741e9c9, is the 31 lowest bits for sha256(starknet)
  • 1470455285', decimal for 0x57a55df5, is the 31 lowest bits for sha256(starkli)

Currently, the Ledger app only enforces the length and the first level of the path.