pub struct SigningKey { /* private fields */ }Expand description
A ECDSA signing (private) key on the STARK curve.
Implementations
Sourceimpl SigningKey
impl SigningKey
Sourcepub fn from_random() -> SigningKey
pub fn from_random() -> SigningKey
Generates a new key pair from a cryptographically secure RNG.
Sourcepub const fn from_secret_scalar(secret_scalar: Felt) -> SigningKey
pub const fn from_secret_scalar(secret_scalar: Felt) -> SigningKey
Constructs SigningKey directly from a secret scalar.
Sourcepub fn from_keystore<P>(
path: P,
password: &str,
) -> Result<SigningKey, KeystoreError>
pub fn from_keystore<P>( path: P, password: &str, ) -> Result<SigningKey, KeystoreError>
Loads the private key from a Web3 Secret Storage Definition keystore.
Sourcepub fn save_as_keystore<P>(
&self,
path: P,
password: &str,
) -> Result<(), KeystoreError>
pub fn save_as_keystore<P>( &self, path: P, password: &str, ) -> Result<(), KeystoreError>
Encrypts and saves the private key to a Web3 Secret Storage Definition JSON file.
Sourcepub const fn secret_scalar(&self) -> Felt
pub const fn secret_scalar(&self) -> Felt
Gets the secret scalar in the signing key.
Sourcepub fn verifying_key(&self) -> VerifyingKey
pub fn verifying_key(&self) -> VerifyingKey
Derives the verifying (public) key that corresponds to the signing key.