pub struct SingleOwnerAccount<P, S>{ /* private fields */ }Expand description
A generic Account implementation for controlling account contracts that only have one signer
using ECDSA the STARK curve.
Implementations
Sourceimpl<P, S> SingleOwnerAccount<P, S>
impl<P, S> SingleOwnerAccount<P, S>
Sourcepub const fn new(
provider: P,
signer: S,
address: Felt,
chain_id: Felt,
encoding: ExecutionEncoding,
) -> SingleOwnerAccount<P, S>
pub const fn new( provider: P, signer: S, address: Felt, chain_id: Felt, encoding: ExecutionEncoding, ) -> SingleOwnerAccount<P, S>
Create a new account controlled by a single signer.
Parameters
provider: AProviderimplementation that provides access to the Starknet network.signer: ASignerimplementation that can generate valid signatures for this account.address: Account contract address.chain_id: Network chain ID.encoding: How__execute__calldata should be encoded.
Sourcepub fn set_block_id(&mut self, block_id: BlockId) -> &SingleOwnerAccount<P, S>
pub fn set_block_id(&mut self, block_id: BlockId) -> &SingleOwnerAccount<P, S>
Sets a new block ID to run queries against.