Types for smart contract deployment and interaction
Structs
- Contract
Factory - A contract factory that acts as a blueprint for deploying Starknet smart contracts using the Universal Deployer Contract.
- Deployment
V3 - Abstraction over contract deployment via the UDC. This type uses
INVOKEv3 transactions under the hood, and hence pays transaction fees in STRK.
Enums
- UdcSelector
- Specifies the Universal Deployer Contract to be used.