HashFunction

Struct HashFunction 

pub struct HashFunction { /* private fields */ }
A hash function that is used in Starknet.

Implementations

Source

impl HashFunction

pub fn stateful(&self) -> StatefulHasher

Creates a new stateful hasher with chosen hash function.

pub fn poseidon() -> HashFunction

Creates a new Poseidon hash function.

pub fn blake2s() -> HashFunction

Creates a new Blake2s hash function.

pub fn hash(&self, x: Felt, y: Felt) -> Felt

Computes the Starknet Poseidon hash of x and y with chosen hash function.

pub fn hash_single(&self, input: Felt) -> Felt

Computes the Starknet hash of a single Felt with chosen hash function.

pub fn hash_many(&self, inputs: &[Felt]) -> Felt

Computes the Starknet hash of an arbitrary number of Felts with chosen hash function.