pub enum TransactionStatus {
NotReceived,
Received,
Pending,
Rejected,
Reverted,
AcceptedOnL2,
AcceptedOnL1,
}Variants
NotReceived
Transaction has not been received yet (i.e. not written to storage)
Received
Transaction was received by the sequenced
Pending
Transaction passed the validation and entered the pending block
Rejected
The transaction failed validation and was skipped (applies both to a pending and actual created block)
Reverted
AcceptedOnL2
Transaction passed the validation and entered a created block
AcceptedOnL1
Transaction was accepted on-chain
Implementations
Sourceimpl TransactionStatus
impl TransactionStatus
Sourcepub const fn is_not_received(&self) -> bool
pub const fn is_not_received(&self) -> bool
Returns true if the transaction status is NotReceived.
Sourcepub const fn is_received(&self) -> bool
pub const fn is_received(&self) -> bool
Returns true if the transaction status is Received.
Sourcepub const fn is_pending(&self) -> bool
pub const fn is_pending(&self) -> bool
Returns true if the transaction status is Pending.
Sourcepub const fn is_rejected(&self) -> bool
pub const fn is_rejected(&self) -> bool
Returns true if the transaction status is Rejected.
Sourcepub const fn is_reverted(&self) -> bool
pub const fn is_reverted(&self) -> bool
Returns true if the transaction status is Reverted.
Sourcepub const fn is_accepted_on_l2(&self) -> bool
pub const fn is_accepted_on_l2(&self) -> bool
Returns true if the transaction status is AcceptedOnL2.
Sourcepub const fn is_accepted_on_l1(&self) -> bool
pub const fn is_accepted_on_l1(&self) -> bool
Returns true if the transaction status is AcceptedOnL1.