pub struct DeclareV3TransactionRequest {
pub contract_class: Arc<CompressedSierraClass>,
pub compiled_class_hash: Felt,
pub sender_address: Felt,
pub signature: Vec<Felt>,
pub nonce: Felt,
pub nonce_data_availability_mode: DataAvailabilityMode,
pub fee_data_availability_mode: DataAvailabilityMode,
pub resource_bounds: ResourceBoundsMapping,
pub tip: u64,
pub paymaster_data: Vec<Felt>,
pub account_deployment_data: Vec<Felt>,
pub is_query: bool,
}Fields
contract_class: Arc<CompressedSierraClass>compiled_class_hash: FeltHash of the compiled class obtained by running starknet-sierra-compile on the Sierra
class. This is required because at the moment, Sierra compilation is not proven, allowing
the sequencer to run arbitrary code if this is not signed. It’s expected that in the future
this will no longer be required.
sender_address: FeltThe address of the account contract sending the declaration transaction.
signature: Vec<Felt>Additional information given by the caller that represents the signature of the transaction.
nonce: FeltA sequential integer used to distinguish between transactions and order them.
nonce_data_availability_mode: DataAvailabilityModefee_data_availability_mode: DataAvailabilityModeresource_bounds: ResourceBoundsMappingtip: u64paymaster_data: Vec<Felt>account_deployment_data: Vec<Felt>is_query: boolTrait Implementations
Sourceimpl Debug for DeclareV3Transaction
impl Debug for DeclareV3Transaction
Sourceimpl Serialize for DeclareV3Transaction
impl Serialize for DeclareV3Transaction
Sourcefn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl TryFrom<BroadcastedDeclareTransactionV3> for DeclareV3Transaction
impl TryFrom<BroadcastedDeclareTransactionV3> for DeclareV3Transaction
Sourcefn try_from(
value: BroadcastedDeclareTransactionV3,
) -> Result<DeclareV3Transaction, <DeclareV3Transaction as TryFrom<BroadcastedDeclareTransactionV3>>::Error>
fn try_from( value: BroadcastedDeclareTransactionV3, ) -> Result<DeclareV3Transaction, <DeclareV3Transaction as TryFrom<BroadcastedDeclareTransactionV3>>::Error>
Performs the conversion.