pub enum SignerInteractivityContext<'a> {
Execution {
calls: &'a [Call],
},
Other,
}Expand description
Context for helping signer implementations make decisions on whether to act interactively or not, useful for signers with dynamic interactivity.
This type only exposes execution details as context, with everything else falling under the
Other variant, as it’s deemed very much pointless to act differently in those scenarios.
When an execution is requested, only the list of calls is exposed.
Variants
Execution
An execution is being requested.
Other
A class declaration or account deployment is being requested.